@@ -1,6 +1,7 @@
 import datetime
 import json
 import six
+import pytz
 
 """
 Adds the ability to send date and datetime objects to the API
@@ -13,7 +14,9 @@ DATE_FORMAT = "%Y-%m-%d"
 
 def _datetime_encoder(obj):
     if isinstance(obj, datetime.datetime):
-        return datetime.datetime.strftime(obj, DATETIME_FORMAT)
+        if obj.utcoffset() is None:  # support for <= 3.3
+            obj = pytz.utc.localize(obj)
+        return datetime.datetime.strftime(obj.astimezone(pytz.utc), DATETIME_FORMAT)
     if isinstance(obj, datetime.date):
         return datetime.datetime.strftime(obj, DATE_FORMAT)
 
@@ -31,13 +34,17 @@ def _datetime_decoder(dict_):
             try:
                 # The api always returns times like this
                 # 2014-07-25T09:12:24.735
-                datetime_obj = datetime.datetime.strptime(value, DATETIME_FORMAT)
+                datetime_obj = pytz.utc.localize(
+                    datetime.datetime.strptime(value, DATETIME_FORMAT)
+                )
                 dict_[key] = datetime_obj
             except (ValueError, TypeError):
                 try:
                     # The api always returns times like this
                     # 2014-07-25T09:12:24.735
-                    datetime_obj = datetime.datetime.strptime(value, DATE_FORMAT)
+                    datetime_obj = pytz.utc.localize(
+                        datetime.datetime.strptime(value, DATE_FORMAT)
+                    )
                     dict_[key] = datetime_obj.date()
                 except (ValueError, TypeError):
                     continue
